@@ -50,7 +50,8 @@ Bool addHextile = True;
 Bool useBGR233 = False;
 Bool forceOwnCmap = False;
 Bool forceTruecolour = False;
-Bool resurface = True;
+Bool resurface = False;
+Bool reconnect = False;
 int requestedDepth = 0;
 
 char *geometry = NULL;
@@ -74,7 +75,13 @@ Bool debug = False;
 
 void usage()
 {
-    fprintf(stderr,"\n"
+    fprintf(stderr,
+	    "x2vnc version " VERSION ", Copyright (C) 2000 Fredrik Hubinette\n"
+	    "Based on vncviewer which is copyright by AT&T\n"
+	    "x2vnc comes with ABSOLUTELY NO WARRANTY. This is free software,\n"
+	    "and you are welcome to redistribute it under certain conditions.\n"
+            "See the file COPYING in the x2vnc source for details.\n"
+	    "\n"
 	    "usage: %s [<options>] <host>:<display#>\n"
 	    "       %s [<options>] -listen [<display#>]\n"
 	    "\n"
@@ -82,7 +89,7 @@ void usage()
 	    "              [-display <display>] [-shared]\n"
 	    "              [-north] [-south] [-east] [-west]\n"
 	    "              [-passwd <passwd-file>]\n"
-	    "              [-resurface]\n"
+	    "              [-resurface] [-edgewidth width]\n"
 	    ,programName,programName);
     exit(1);
 }
@@ -104,40 +111,32 @@ processArgs(int argc, char **argv)
 	    displayname = argv[i];
 
 	} else if (strcmp(argv[i],"-east") == 0) {
-
 	  edge=EDGE_EAST;
-
 	} else if (strcmp(argv[i],"-west") == 0) {
-
 	  edge=EDGE_WEST;
-
 	} else if (strcmp(argv[i],"-north") == 0) {
-
 	  edge=EDGE_NORTH;
-
 	} else if (strcmp(argv[i],"-south") == 0) {
-
 	  edge=EDGE_SOUTH;
-
 	} else if (strcmp(argv[i],"-resurface") == 0) {
-
 	  resurface=True;
-
 	} else if (strcmp(argv[i],"-shared") == 0) {
-
 	    shareDesktop = True;
-
+	} else if (strcmp(argv[i],"-edgewidth") == 0) {
+	  extern int edge_width;
+	    if (++i >= argc) usage();
+	    edge_width = atoi(argv[i]);
+	    if(edge_width < 1)
+	    {
+	      fprintf(stderr,"x2vnc: -edgewidth cannot be less than 1\n");
+	      exit(1);
+	    }
 	} else if (strcmp(argv[i],"-passwd") == 0) {
-
 	    if (++i >= argc) usage();
 	    passwdFile = argv[i];
-
 	} else if (strcmp(argv[i],"-debug") == 0) {
-
 	    debug = True;
-
 	} else if (strcmp(argv[i],"-listen") == 0) {
-
 	    if (argumentSpecified) usage();
 
 	    listenSpecified = True;
