@@ -167,7 +167,11 @@ InitialiseRFBConnection(int sock)
 	if (!ReadExact(sock, (char *)challenge, CHALLENGESIZE)) return False;
 
 	if (passwdFile) {
-	    passwd = vncDecryptPasswdFromFile(passwdFile);
+	  if (!(passwd = vncDecryptPasswdFromFile(passwdFile))) {
+	    fprintf(stderr,"%s: Couldn't open password file: %s\n",
+		    programName, passwdFile);
+	    return False;
+	  }
 	} else {
 	    passwd = getpass("Password: ");
 	    if (strlen(passwd) == 0) {
@@ -325,8 +329,10 @@ SendPointerEvent(int x, int y, int buttonMask)
 
     pe.type = rfbPointerEvent;
     pe.buttonMask = buttonMask;
-    if (x < 0) x = 0;
+#if 0
+   if (x < 0) x = 0;
     if (y < 0) y = 0;
+#endif
     pe.x = Swap16IfLE(x);
     pe.y = Swap16IfLE(y);
     return WriteExact(rfbsock, (char *)&pe, sz_rfbPointerEventMsg);
@@ -454,8 +460,6 @@ HandleRFBServerMessage()
 		    if (!ReadExact(rfbsock, buffer,bytesPerLine * linesToRead))
 			return False;
 
-//		    CopyDataToScreen((CARD8 *)buffer, rect.r.x, rect.r.y,
-//				     rect.r.w, linesToRead);
 
 		    rect.r.h -= linesToRead;
 		    rect.r.y += linesToRead;
@@ -634,6 +638,7 @@ HandleRFBServerMessage()
     case rfbServerCutText:
     {
 	char *str;
+        XWindowAttributes   attrs;
 
 	if (!ReadExact(rfbsock, ((char *)&msg) + 1,
 			 sz_rfbServerCutTextMsg - 1))
@@ -646,10 +651,12 @@ HandleRFBServerMessage()
 	if (!ReadExact(rfbsock, str, msg.sct.length))
 	    return False;
 
-	XSelectInput(dpy, DefaultRootWindow(dpy), 0);
+        XGetWindowAttributes(dpy, RootWindow(dpy, 0), &attrs);
+	XSelectInput(dpy, RootWindow(dpy, 0),
+                     attrs.your_event_mask & ~PropertyChangeMask);
 	XStoreBytes(dpy, str, msg.sct.length);
 	XSetSelectionOwner(dpy, XA_PRIMARY, None, CurrentTime);
-	XSelectInput(dpy, DefaultRootWindow(dpy), PropertyChangeMask);
+	XSelectInput(dpy, RootWindow(dpy, 0), attrs.your_event_mask);
 
 	free(str);
 
